@@ -71,7 +71,7 @@ def ProcessFiles(sourceFile):
         sourceContent = (file.read())
         file.close()
         for i in range (len(targetLangs)):
-            PrGreen('Traslating "' + sourceFile + '" from "' + sourceLang + '" to "' + targetLangs[i] + '"')
+            PrLightPurple('Traslating "' + sourceFile + '" from "' + sourceLang + '" to "' + targetLangs[i] + '"')
             langCombo = sourceLang + '-' + targetLangs[i]
             targetContent = ''
             if fileName[-3:] == 'yml':
@@ -185,8 +185,18 @@ def PrLightPurple(skk):
 #--------------------------------
 
 def RepoCheck():
+    global sourceDir
+    if sourceLang not in os.listdir():
+        if sourceLang + '_' not in list(map(lambda x: x[:3], os.listdir())):
+            PrRed('\nNo directory for source language files has been found!\n Add or rename the directory with the ISO 639-1 code for its language')
+        else:
+            if len(list(filter(lambda x: x == sourceLang + '_', map(lambda x: x[:3], os.listdir())))) > 1:
+                PrRed('\nThere are more than one directory named with source language code.\n Please designate only one.')
+            else:
+                sourceDir = list(filter(lambda x: x[:3] == sourceLang + '_', os.listdir()))[0]
+    else:
+        sourceDir = sourceLang
     if sourceDir not in os.listdir():
-        PrRed('\nThe directory "' + sourceDir + '" for source files has not been found!')
         exit()
 
     for lang in targetLangs:
@@ -219,7 +229,6 @@ def root():
     global apiTradKey
     global sourceLang
     global targetLangs
-    global sourceDir
     global configs
     init()
     try:
@@ -240,15 +249,14 @@ def root():
         }
         with open(os.path.expanduser('~') + '/' + 'tradocs.config.json', 'w+') as file:
             json.dump(configs, file)
-    sourceDir = '_'.join(sourceLang.split('-')).lower()
 
 @root.command()
 @click.option('-k', '--api-key', type=str)
 @click.option('-s', '--source', type=str)
 @click.option('-t', '--target', type=str)
 def config(api_key, source, target):
-    global configs
     """Show and set configuration"""
+    global configs
     if not (api_key or source or target):
         print(' Source language:\t' + configs['SOURCE'])
         print(' Target languages:\t' + ' '.join(configs['TARGET']))
